@@ -13,6 +13,7 @@ import re
 from kabaret import flow
 from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.subprocess_manager.flow import RunAction
+from .dependency import get_dependencies
 
 from .maputils import ItemMap, CreateGenericAction, ClearMapAction, RemoveGenericAction
 from libreflow.baseflow.runners import Runner, PythonRunner
@@ -387,14 +388,15 @@ class RequestAs(flow.Action):
 
     _revision = flow.Parent()
     priority = flow.IntParam(50)
-    requesting_site_name = flow.Param(None, RequestingSiteChoiceValue).ui(label="Requesting site")
-    requested_site_name = flow.Param(None, RequestedSiteChoiceValue).ui(label="Site to query")
+    target_site = flow.Param(None, RequestingSiteChoiceValue).ui(label="Requesting site")
+    source_site = flow.Param(None, RequestedSiteChoiceValue).ui(label="Site to query")
+    include_dependencies = flow.SessionParam(True).ui(editor='bool')
 
     def get_buttons(self):
-        site_names = self.requested_site_name.choices()
+        site_names = self.source_site.choices()
         # Actually, an existing revision implies there is at least one
         # site on which it is available, which is the source site
-        self.requested_site_name.set(site_names[0])
+        self.source_site.set(site_names[0])
 
         return ["Request", "Cancel"]
     
@@ -409,11 +411,11 @@ class RequestAs(flow.Action):
         if button == "Cancel":
             return
         
-        requesting_site_name = self.requesting_site_name.get()
+        target_site = self.target_site.get()
 
         # Get requesting and requested sites
         sites = self.root().project().get_working_sites()
-        requesting_site = sites[requesting_site_name]
+        requesting_site = sites[target_site]
         
         # Add a download job for the requesting site
         requesting_site.get_queue().submit_job(
@@ -421,12 +423,19 @@ class RequestAs(flow.Action):
             init_status="WAITING",
             emitter_oid=self._revision.oid(),
             user=self.root().project().get_user(),
-            studio=requesting_site_name,
+            studio=target_site,
             priority=self.priority.get(),
         )
-        self._revision.set_sync_status("Requested", site_name=requesting_site_name)
+        self._revision.set_sync_status("Requested", site_name=target_site)
         self._revision._revisions.touch()
         
+        # Request dependencies if required
+        if self.include_dependencies.get():
+            request_deps = self._revision.request_dependencies
+            request_deps.target_site.set(self.target_site.get())
+            request_deps.predictive_only.set(False)
+            request_deps.run(None)
+        
         # Check if the version is not available on the exchange server
         exchange_site = self.root().project().get_exchange_site()
         revision_status = self._revision.get_sync_status(exchange=True)
@@ -438,7 +447,7 @@ class RequestAs(flow.Action):
             self.root().project().synchronization.touch()
             return self.get_result()
 
-        requested_site = sites[self.requested_site_name.get()]
+        requested_site = sites[self.source_site.get()]
 
         # Check if the source version upload is not already requested
         for job in requested_site.get_jobs(type="Upload", status="WAITING"):
@@ -455,7 +464,7 @@ class RequestAs(flow.Action):
             init_status="WAITING",
             emitter_oid=self._revision.oid(),
             user=self.root().project().get_user(),
-            studio=requesting_site_name,
+            studio=target_site,
             priority=self.priority.get(),
         )
 
@@ -467,10 +476,10 @@ class Request(RequestAs):
 
     _revision = flow.Parent()
     priority = flow.IntParam(50)
-    requesting_site_name = flow.Param("").ui(hidden=True)
+    target_site = flow.Param("").ui(hidden=True)
 
     def get_buttons(self):
-        self.requesting_site_name.set(
+        self.target_site.set(
             self.root().project().get_current_site().name()
         )
 
@@ -739,6 +748,7 @@ class WorkingSite(Site):
             "Temporary option as long as synchronisation is manual."
         )
     )
+    is_kitsu_admin = flow.BoolParam(False)
 
     root_folder = flow.Computed(cached=True)
     root_windows_folder = flow.Param()
@@ -747,6 +757,7 @@ class WorkingSite(Site):
     
     sync_dl_max_connections = flow.IntParam(1)
     sync_up_max_connections = flow.IntParam(1)
+    pool_names = flow.OrderedStringSetParam()
 
     queue = flow.Child(Queue)
 
@@ -933,12 +944,8 @@ class RequestRevisionsAs(flow.Action):
     pattern = flow.SessionParam("").watched().ui(
         placeholder="Revision oid pattern"
     )
-    requesting_site_name = flow.Param("default", WorkingSiteChoiceValue).watched().ui(
-        label="Requesting site"
-    )
-    requested_site_name = flow.Param("default", WorkingSiteChoiceValue).watched().ui(
-        label="Site to query"
-    )
+    source_site = flow.Param("default", WorkingSiteChoiceValue).watched()
+    target_site = flow.Param("default", WorkingSiteChoiceValue).watched()
     revision_oids = flow.SessionParam("").ui(
         editor="textarea",
         html=True,
@@ -953,9 +960,9 @@ class RequestRevisionsAs(flow.Action):
         return "Request revisions"
     
     def child_value_changed(self, child_value):
-        if child_value in (self.requesting_site_name, self.requested_site_name):
+        if child_value in (self.target_site, self.source_site):
             msg = "<h2>%s</h2>" % self._title()
-            if self.requested_site_name.get() == self.requesting_site_name.get():
+            if self.source_site.get() == self.target_site.get():
                 msg += (
                     "<font color=#D5000D>"
                     "Requested and requesting sites can't be the same."
@@ -980,7 +987,7 @@ class RequestRevisionsAs(flow.Action):
         return oids
 
     def get_buttons(self):
-        self.requested_site_name.set(self.requested_site_name.choices()[0])
+        self.source_site.set(self.source_site.choices()[0])
         self.revision_oids.set("")
         self._oids = []
 
@@ -1065,16 +1072,16 @@ class RequestRevisionsAs(flow.Action):
             oid = o.oid()
 
             if hasattr(o, 'request_as') and o.ready_for_sync.get():
-                requested_site_name = self.requested_site_name.get()
-                requesting_site_name = self.requesting_site_name.get()
+                source_site = self.source_site.get()
+                target_site = self.target_site.get()
 
-                if not requesting_site_name in o.request_as.requesting_site_name.choices():
-                    oid += f" <font color='red'>Available on {requesting_site_name}</font>"
-                elif not requested_site_name in o.request_as.requested_site_name.choices():
-                    oid += f" <font color='red'>Not available on {requested_site_name}</font>"
+                if not target_site in o.request_as.target_site.choices():
+                    oid += f" <font color='red'>Available on {target_site}</font>"
+                elif not source_site in o.request_as.source_site.choices():
+                    oid += f" <font color='red'>Not available on {source_site}</font>"
                 else:
-                    o.request_as.requested_site_name.set(requested_site_name)
-                    o.request_as.requesting_site_name.set(requesting_site_name)
+                    o.request_as.source_site.set(source_site)
+                    o.request_as.target_site.set(target_site)
                     o.request_as.run(None)
                     oid += " <font color='green'>OK</font>"
             else:
