@@ -264,17 +264,9 @@ class Users(flow.Map):
         return user.status.get() == "Admin"
     
     def add_user(self, kitsu_id, status="User"):
-        def replace(s, substrings, rep):
-            res = s
-            for ss in substrings:
-                res = res.replace(ss, rep)
-            
-            return res
+        name = self.get_user_name(kitsu_id)
 
-        name = kitsu_id.split('@')[0]
-        name = replace(name, ['.', '-', '_'], '')
-
-        if self.has_mapped_name(name):
+        if name is None or self.has_mapped_name(name):
             return None
 
         user = self.add(name)
@@ -284,11 +276,18 @@ class Users(flow.Map):
         return user
     
     def get_user_name(self, kitsu_id):
-        for user in self.mapped_items():
-            if user.kitsu_id.get() == kitsu_id:
-                return user.name()
+        def replace(s, substrings, rep):
+            res = s
+            for ss in substrings:
+                res = res.replace(ss, rep)
+            
+            return res
+
+        name = kitsu_id.split('@')[0]
+        name = replace(name, ['.', '-', '_'], '')
+        name = name.lower()
         
-        return None
+        return name
 
     def _fill_row_cells(self, row, item):
         row["ID"] = item.name()
